SecurityAuditEvent class
Detailed security audit log event details.
Constructors
Properties
- domain → String
-
final
-
expectedPins
→ Set<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBypassed → bool
-
final
- isPassed → bool
-
final
- presentedFingerprint → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited